<?php
/**
 * Additional features to allow styling of the templates
 *
 * @package WordPress
 * @subpackage Rango
 * @since 1.0
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function ftc_body_classes( $classes ) {
	global $smof_data;
	// Add class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Add class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	// Add class if we're viewing the Customizer for easier styling of theme options.
	if ( is_customize_preview() ) {
		$classes[] = 'ftc-customizer';
	}

	// Add class on front page.
	if ( is_front_page() && 'posts' !== get_option( 'show_on_front' ) ) {
		$classes[] = 'ftc-front-page';
	}

	// Add a class if there is a custom header.
	if ( has_header_image() ) {
		$classes[] = 'has-header-image';
	}

	// Add class if sidebar is used.
	if ( is_active_sidebar( 'sidebar-1' ) && ! is_page() ) {
		$classes[] = 'has-sidebar';
	}

	// Add class if the site title and tagline is hidden.
	if ( 'blank' === get_header_textcolor() ) {
		$classes[] = 'title-tagline-hidden';
	}

	// Get the colorscheme or the default if there isn't one.
	$colors = ftc_sanitize_colorscheme( get_theme_mod( 'colorscheme', 'light' ) );
	$classes[] = 'colors-' . $colors;

	// 20220721 - add body class main style	
	// Set theme-option param by page-option if page-option isset
    if(false)if(isset($ftc_page_datas['ftc_critical_css']) && trim($ftc_page_datas['ftc_critical_css'])){
        $smof_data['ftc_css_main'] = $ftc_page_datas['ftc_critical_css'];
    }
    
    if(false)if(isset($smof_data['ftc_css_main']) && $smof_data['ftc_css_main']){
        $arStyle = explode(',', trim($smof_data['ftc_css_main']));
        foreach ($arStyle as $strStyle){
            $arDetailStyle = explode('-', $strStyle); // folder-filename (.css)            
            if(count($arDetailStyle) == 2){ // Mang co 2 phan tu thi OK
                $classes[] = trim($arDetailStyle[0]) .'-'. trim($arDetailStyle[1]);
            }
        }
    }
    // 20220721- End of add body class main style

	return $classes;
}
add_filter( 'body_class', 'ftc_body_classes' );

/**
 * Count our number of active panels.
 *
 * Primarily used to see if we have any panels active, duh.
 */
function ftc_panel_count() {

	$panel_count = 0;

	/**
	 * Filter number of front page sections in Rango.
	 *
	 * @since Rango 1.0
	 *
	 * @param $num_sections integer
	 */
	$num_sections = apply_filters( 'ftc_front_page_sections', 4 );

	// Create a setting and control for each of the sections available in the theme.
	for ( $i = 1; $i < ( 1 + $num_sections ); $i++ ) {
		if ( get_theme_mod( 'panel_' . $i ) ) {
			$panel_count++;
		}
	}

	return $panel_count;
}

/**
 * Checks to see if we're on the homepage or not.
 */
function ftc_is_frontpage() {
	return ( is_front_page() && ! is_home() );
}
/*** Vertical Menu Heading ***/
if( !function_exists ('ftc_get_vertical_menu_heading') ){
	function ftc_get_vertical_menu_heading(){
		$locations = get_nav_menu_locations();
		if( isset($locations['vertical']) ){
			$menu = wp_get_nav_menu_object($locations['vertical']);
			if( isset( $menu->name ) ){
				return $menu->name;
			}
			else{
				return esc_html__('Shop by category', 'rango');
			}
		}
		return '';
	}
}

// function to display number of posts.
function get_post_views($postID){
    $count_key = 'post_views_count';
    $count = get_post_meta($postID, $count_key, true);
    if($count==''){
        delete_post_meta($postID, $count_key);
        add_post_meta($postID, $count_key, '0');
        return "0";
    }
    return $count;
}

// function to count views.
function set_post_views($postID) {
    $count_key = 'post_views_count';
    $count = get_post_meta($postID, $count_key, true);
    if($count==''){
        $count = 0;
        delete_post_meta($postID, $count_key);
        add_post_meta($postID, $count_key, '0');
    }else{
        $count++;
        update_post_meta($postID, $count_key, $count);
    }
}

// Is Active Mega Main Menu 
if( !function_exists('ftc_has_megamainmenu') ){
	function ftc_has_megamainmenu(){
		$_actived = apply_filters('active_plugins', get_option('active_plugins'));
		if( in_array("mega_main_menu/mega_main_menu.php", $_actived) ){
			return true;
		}
		return false;
	}
}